Class: Crep::AppSource
- Inherits:
-
Object
- Object
- Crep::AppSource
- Defined in:
- lib/crep/model/app_source/app_source.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#version ⇒ Object
readonly
Returns the value of attribute version.
Instance Method Summary collapse
- #apps ⇒ Object
- #configure ⇒ Object
-
#versions(_app_identifier) ⇒ Object
versions returns the versions for the given app identifier.
-
#versions_for_bundle_identifier(_bundle_identifier) ⇒ Object
versions_for_bundle_identifier returns the versions for the first found app with the given bundle identifier.
Instance Attribute Details
#version ⇒ Object (readonly)
Returns the value of attribute version.
5 6 7 |
# File 'lib/crep/model/app_source/app_source.rb', line 5 def version @version end |
Instance Method Details
#apps ⇒ Object
11 12 13 |
# File 'lib/crep/model/app_source/app_source.rb', line 11 def apps raise 'AppSource subclass has to implement the `apps` method.' end |
#configure ⇒ Object
7 8 9 |
# File 'lib/crep/model/app_source/app_source.rb', line 7 def configure CrepLogger.info('Configuration of the CrashSource can happen in the `configure` method') end |
#versions(_app_identifier) ⇒ Object
versions returns the versions for the given app identifier
21 22 23 |
# File 'lib/crep/model/app_source/app_source.rb', line 21 def versions(_app_identifier) raise 'AppSource subclass has to implement the `versions` method.' end |
#versions_for_bundle_identifier(_bundle_identifier) ⇒ Object
versions_for_bundle_identifier returns the versions for the first found app with the given bundle identifier
16 17 18 |
# File 'lib/crep/model/app_source/app_source.rb', line 16 def versions_for_bundle_identifier(_bundle_identifier) raise 'AppSource subclass has to implement the `versions_for_bundle_identifier` method.' end |